summaryrefslogtreecommitdiff
path: root/src/library/scala/collection/immutable/List.scala
diff options
context:
space:
mode:
authorPaul Phillips <paulp@improving.org>2009-05-08 18:24:05 +0000
committerPaul Phillips <paulp@improving.org>2009-05-08 18:24:05 +0000
commitf3c0640e3d7270795cc15dc923d811074c0836d7 (patch)
treec88f2c71c1ecd831c228f8e12171d07f3ea6aee0 /src/library/scala/collection/immutable/List.scala
parent75d487d831dfa388c4c3683eedd0db16491a048a (diff)
downloadscala-f3c0640e3d7270795cc15dc923d811074c0836d7.tar.gz
scala-f3c0640e3d7270795cc15dc923d811074c0836d7.tar.bz2
scala-f3c0640e3d7270795cc15dc923d811074c0836d7.zip
4 out of 5 spelling bee champs say: Traversable
Diffstat (limited to 'src/library/scala/collection/immutable/List.scala')
-rwxr-xr-xsrc/library/scala/collection/immutable/List.scala8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/library/scala/collection/immutable/List.scala b/src/library/scala/collection/immutable/List.scala
index 4670539917..503deecf06 100755
--- a/src/library/scala/collection/immutable/List.scala
+++ b/src/library/scala/collection/immutable/List.scala
@@ -25,7 +25,7 @@ import generic.{SequenceFactory, Builder, BuilderFactory, LinearSequenceTemplate
*/
sealed abstract class List[+A] extends LinearSequence[A] with Product with LinearSequenceTemplate[A, List[A]] {
- import collection.{Iterable, Traversible, Sequence, Vector}
+ import collection.{Iterable, Traversable, Sequence, Vector}
/** Returns true if the list does not contain any elements.
* @return <code>true</code>, iff the list is empty.
@@ -48,7 +48,7 @@ sealed abstract class List[+A] extends LinearSequence[A] with Product with Linea
/** Creates a list buffer as builder for this class */
override protected[this] def newBuilder = List.newBuilder
- override def traversibleBuilder[B]: Builder[B, List[B], Any] = List.newBuilder[B]
+ override def traversableBuilder[B]: Builder[B, List[B], Any] = List.newBuilder[B]
// New methods in List
@@ -141,9 +141,9 @@ sealed abstract class List[+A] extends LinearSequence[A] with Product with Linea
// Overridden methods from IterableTemplate or overloaded variants of such methods
/** Create a new list which contains all elements of this list
* followed by all elements of Traversible `that'
*/
- override def ++[B >: A, That](that: Traversible[B])(implicit bf: BuilderFactory[B, That, List[A]]): That = {
+ override def ++[B >: A, That](that: Traversable[B])(implicit bf: BuilderFactory[B, That, List[A]]): That = {
val b = bf(this)
if (b.isInstanceOf[ListBuffer[_]]) (this ::: that.toList).asInstanceOf[That]
else super.++(that)
@@ -141,9 +141,9 @@ sealed abstract class List[+A] extends LinearSequence[A] with Product with Linea
// Overridden methods from IterableTemplate or overloaded variants of such methods
/** Create a new list which contains all elements of this list
- * followed by all elements of Traversible `that'
+ * followed by all elements of Traversable `that'
*/